@@ -1,4 +1,4 @@
-VERSION='1.9.2'
+VERSION='1.10.0'
 
 from cx_Freeze import setup, Executable
 import os
@@ -16,8 +16,18 @@ include_files = [
 ]
 
 
+def clean_build():
+    dirs = os.listdir('build')
+    keep = ['mo', 'lib']
+    for d in dirs:
+        if d not in keep:
+            shutil.rmtree(os.path.join('build', d))
+
+
+clean_build()
+
+
 def addfile(relpath, warn_missing=False):
-    global include_files
     f = os.path.join(sys.prefix, relpath)
     if warn_missing and not os.path.isfile(f):
         print("{} cannot be found.".format(f), file=sys.stderr)
@@ -26,9 +36,12 @@ def addfile(relpath, warn_missing=False):
 
 
 def addlocale(name):
+    langs = os.listdir('build/mo')
     for path in glob.glob(os.path.join(sys.prefix,
                                        "share/locale/*/LC_MESSAGES/{}.mo".format(name))):
-        addfile(os.path.relpath(path, sys.prefix))
+        lang = os.path.split(os.path.split(os.path.split(path)[0])[0])[1]
+        if lang in langs:
+            addfile(os.path.relpath(path, sys.prefix))
 
 
 addlocale("gtk30")
@@ -98,9 +111,12 @@ for dll in required_dlls:
     fn = 'lib' + dll + '.dll'
     include_files.append((os.path.join(sys.prefix, 'bin', fn), fn))
 
-# zlib1 is first loaded by a DLL located in lib
+# Avoid loading wrong dll: Put the dll where it will be searched for first.
+# (That is the folder from where the dll load request originate)
 include_files.append((os.path.join(sys.prefix, 'bin', 'zlib1.dll'),
                       os.path.join('lib', 'zlib1.dll'),))
+include_files.append((os.path.join(sys.prefix, 'bin', 'libffi-8.dll'),
+                      os.path.join('lib', 'libffi-8.dll'),))
 
 required_gi_namespaces = [
     "Gtk-3.0",
@@ -116,6 +132,7 @@ required_gi_namespaces = [
     "Poppler-0.18",
     "HarfBuzz-0.0",
     "Handy-1",
+    "freetype2-2.0",
 ]
 
 for ns in required_gi_namespaces:
@@ -146,7 +163,7 @@ build_options = dict(
     packages=['gi', 'packaging', 'pikepdf'],
     excludes=['tkinter', 'test'],
     # manually added to the lib folder
-    bin_excludes=['zlib1.dll'],
+    bin_excludes=['zlib1.dll', 'libffi-8.dll'],
     include_files=include_files,
 )
 
